pub async fn apply<St: ComponentStore>(store: &St, id: &Id, event: &Event)Expand description
Write an event back as components (spec 7 presence-as-capability): a
collection that becomes empty is removed, not stored empty.
pub async fn apply<St: ComponentStore>(store: &St, id: &Id, event: &Event)Write an event back as components (spec 7 presence-as-capability): a
collection that becomes empty is removed, not stored empty.